# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKTransformPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkScaleTransformPython
else:
    import _itkScaleTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkArrayPython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.ITKCommonBasePython
import itk.itkArray2DPython
import itk.itkMatrixOffsetTransformBasePython

def itkScaleTransformD2_New():
    return itkScaleTransformD2.New()

class itkScaleTransformD2(itk.itkMatrixOffsetTransformBasePython.itkMatrixOffsetTransformBaseD22):
    r"""Proxy of C++ itkScaleTransformD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScaleTransformD2_Pointer"""
        return _itkScaleTransformPython.itkScaleTransformD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScaleTransformD2_Pointer"""
        return _itkScaleTransformPython.itkScaleTransformD2_Clone(self)

    def SetScale(self, scale):
        r"""
        SetScale(self, scale)

        Parameters
        ----------
        scale: itkFixedArrayD2 const &

        """
        return _itkScaleTransformPython.itkScaleTransformD2_SetScale(self, scale)

    def ComputeMatrix(self):
        r"""ComputeMatrix(self)"""
        return _itkScaleTransformPython.itkScaleTransformD2_ComputeMatrix(self)

    def Compose(self, other, pre=False):
        r"""
        Compose(self, other, pre=False)

        Parameters
        ----------
        other: itkScaleTransformD2 const *
        pre: bool

        """
        return _itkScaleTransformPython.itkScaleTransformD2_Compose(self, other, pre)

    def Scale(self, scale, pre=False):
        r"""
        Scale(self, scale, pre=False)

        Parameters
        ----------
        scale: itkFixedArrayD2 const &
        pre: bool

        """
        return _itkScaleTransformPython.itkScaleTransformD2_Scale(self, scale, pre)

    def TransformVector(self, *args):
        r"""
        TransformVector(self, vect) -> itkVectorD2

        Parameters
        ----------
        vect: itkVectorD2 const &

        TransformVector(self, vect) -> vnl_vector_fixed< double,2 >

        Parameters
        ----------
        vect: vnl_vector_fixed< double,2 > const &

        """
        return _itkScaleTransformPython.itkScaleTransformD2_TransformVector(self, *args)

    def BackTransform(self, *args):
        r"""
        BackTransform(self, point) -> itkPointD2

        Parameters
        ----------
        point: itkPointD2 const &

        BackTransform(self, vect) -> itkVectorD2

        Parameters
        ----------
        vect: itkVectorD2 const &

        BackTransform(self, vect) -> vnl_vector_fixed< double,2 >

        Parameters
        ----------
        vect: vnl_vector_fixed< double,2 > const &

        BackTransform(self, vect) -> itkCovariantVectorD2

        Parameters
        ----------
        vect: itkCovariantVectorD2 const &

        """
        return _itkScaleTransformPython.itkScaleTransformD2_BackTransform(self, *args)

    def GetInverse(self, inverse):
        r"""
        GetInverse(self, inverse) -> bool

        Parameters
        ----------
        inverse: itkScaleTransformD2 *

        """
        return _itkScaleTransformPython.itkScaleTransformD2_GetInverse(self, inverse)

    def GetScale(self):
        r"""GetScale(self) -> itkFixedArrayD2"""
        return _itkScaleTransformPython.itkScaleTransformD2_GetScale(self)
    __swig_destroy__ = _itkScaleTransformPython.delete_itkScaleTransformD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScaleTransformD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScaleTransformPython.itkScaleTransformD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScaleTransformD2

        Create a new object of the class itkScaleTransformD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScaleTransformD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScaleTransformD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScaleTransformD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScaleTransformD2 in _itkScaleTransformPython:
_itkScaleTransformPython.itkScaleTransformD2_swigregister(itkScaleTransformD2)

def itkScaleTransformD3_New():
    return itkScaleTransformD3.New()

class itkScaleTransformD3(itk.itkMatrixOffsetTransformBasePython.itkMatrixOffsetTransformBaseD33):
    r"""Proxy of C++ itkScaleTransformD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScaleTransformD3_Pointer"""
        return _itkScaleTransformPython.itkScaleTransformD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScaleTransformD3_Pointer"""
        return _itkScaleTransformPython.itkScaleTransformD3_Clone(self)

    def SetScale(self, scale):
        r"""
        SetScale(self, scale)

        Parameters
        ----------
        scale: itkFixedArrayD3 const &

        """
        return _itkScaleTransformPython.itkScaleTransformD3_SetScale(self, scale)

    def ComputeMatrix(self):
        r"""ComputeMatrix(self)"""
        return _itkScaleTransformPython.itkScaleTransformD3_ComputeMatrix(self)

    def Compose(self, other, pre=False):
        r"""
        Compose(self, other, pre=False)

        Parameters
        ----------
        other: itkScaleTransformD3 const *
        pre: bool

        """
        return _itkScaleTransformPython.itkScaleTransformD3_Compose(self, other, pre)

    def Scale(self, scale, pre=False):
        r"""
        Scale(self, scale, pre=False)

        Parameters
        ----------
        scale: itkFixedArrayD3 const &
        pre: bool

        """
        return _itkScaleTransformPython.itkScaleTransformD3_Scale(self, scale, pre)

    def TransformVector(self, *args):
        r"""
        TransformVector(self, vect) -> itkVectorD3

        Parameters
        ----------
        vect: itkVectorD3 const &

        TransformVector(self, vect) -> vnl_vector_fixed< double,3 >

        Parameters
        ----------
        vect: vnl_vector_fixed< double,3 > const &

        """
        return _itkScaleTransformPython.itkScaleTransformD3_TransformVector(self, *args)

    def BackTransform(self, *args):
        r"""
        BackTransform(self, point) -> itkPointD3

        Parameters
        ----------
        point: itkPointD3 const &

        BackTransform(self, vect) -> itkVectorD3

        Parameters
        ----------
        vect: itkVectorD3 const &

        BackTransform(self, vect) -> vnl_vector_fixed< double,3 >

        Parameters
        ----------
        vect: vnl_vector_fixed< double,3 > const &

        BackTransform(self, vect) -> itkCovariantVectorD3

        Parameters
        ----------
        vect: itkCovariantVectorD3 const &

        """
        return _itkScaleTransformPython.itkScaleTransformD3_BackTransform(self, *args)

    def GetInverse(self, inverse):
        r"""
        GetInverse(self, inverse) -> bool

        Parameters
        ----------
        inverse: itkScaleTransformD3 *

        """
        return _itkScaleTransformPython.itkScaleTransformD3_GetInverse(self, inverse)

    def GetScale(self):
        r"""GetScale(self) -> itkFixedArrayD3"""
        return _itkScaleTransformPython.itkScaleTransformD3_GetScale(self)
    __swig_destroy__ = _itkScaleTransformPython.delete_itkScaleTransformD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScaleTransformD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScaleTransformPython.itkScaleTransformD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScaleTransformD3

        Create a new object of the class itkScaleTransformD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScaleTransformD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScaleTransformD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScaleTransformD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScaleTransformD3 in _itkScaleTransformPython:
_itkScaleTransformPython.itkScaleTransformD3_swigregister(itkScaleTransformD3)

